@@ -18,6 +18,7 @@ import tempfile
 import unittest
 
 topdir = None
+features = "/etc/apparmor.d/cache/.features"
 debugging = False
 
 
@@ -54,6 +55,10 @@ def debug(s):
     print("DEBUG: %s" % s)
 
 
+def msg(s):
+    print("INFO: %s" % s)
+
+
 class T(unittest.TestCase):
     def setUp(self):
         '''Setup for tests'''
@@ -88,7 +93,7 @@ class T(unittest.TestCase):
         p['template_variables']['APP_VERSION'] = self.version
         p['template_variables']['APP_ID_DBUS'] = self.app_id_dbus
         p['template_variables']['APP_PKGNAME_DBUS'] = self.app_pkgname_dbus
-        p['template_variables']['CLICK_DIR'] = '/opt/click.ubuntu.com'
+        p['template_variables']['INSTALL_DIR'] = '/opt/click.ubuntu.com'
 
         self.security['profiles'][self.profile_name] = p
 
@@ -128,6 +133,7 @@ class T(unittest.TestCase):
 
     def _easyprof(self):
         '''Run easyprof'''
+        global features
         contents = self.emit_json()
         debug("\n" + contents)
         out_dir = os.path.join(self.tmpdir, "out")
@@ -145,9 +151,27 @@ class T(unittest.TestCase):
                         "aa-easyprof exited with error:\n%s\n%s\n[%d]" %
                         (contents, out, rc))
 
+        # easyprof will run the verify step but if the features file is
+        # missing it will downgrade its supported rules. Therefore, if we want
+        # to make sure all the rules are syntactically correct, we need to
+        # supply our own features file for when we are running on the buildd,
+        # etc.
+        run_separate_verify = False
+        features = "/etc/apparmor.d/cache/.features"
+        if not os.path.exists(features):
+            features = os.path.join(topdir, "tests/aa.features")
+            run_separate_verify = True
+
         for fn in glob.glob("%s/*" % out_dir):
             debug(fn)
             debug("\n%s" % open(fn, 'r').read())
+            if run_separate_verify:
+                rc, out = cmd(['apparmor_parser', '-QTK',
+                               '--features-file', features,
+                               fn])
+                self.assertTrue(rc == 0,
+                                "apparmor_parser exited with error: "
+                                "\n%s\n%s\n[%d]" % (open(fn).read(), out, rc))
 
         if os.path.exists(out_dir):
             recursive_rm(out_dir)
@@ -210,6 +234,9 @@ if __name__ == '__main__':
     if len(sys.argv) > 1 and sys.argv[1] == '-d':
         debugging = True
 
+    if not os.path.exists(features):
+        msg("Mocking features file for apparmor_parser")
+
     # run the tests
     suite = unittest.TestSuite()
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(T))
